var _storedInfo;

import { getConfig } from './config.js';
var FIELDS = {
  clientId: 'client_id',
  sessionId: 'session_id'
};
var storedInfo = (_storedInfo = {}, _storedInfo[FIELDS.clientId] = null, _storedInfo[FIELDS.sessionId] = null, _storedInfo);
var scriptPromise;
export var loadScript = function loadScript(src) {
  return new Promise(function (resolve, reject) {
    var s = document.createElement('script');
    s.src = src;
    s.onload = resolve;
    s.onerror = reject;
    document.head.appendChild(s);
  });
};

var getGoogleField = function getGoogleField(field) {
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId'); // 1. Check we have the needed config to load the script

  if (!googleAnalyticsMeasurementId) return Promise.resolve(false); // 2. Check we have already a clientId stored

  if (storedInfo[field]) return Promise.resolve(storedInfo[field]); // 3. Load Gtag and retrieve async clientId from Google

  var gtagScript = "https://www.googletagmanager.com/gtag/js?id=" + googleAnalyticsMeasurementId;
  return new Promise(function (resolve) {
    var _scriptPromise;

    // to avoid loading twice the script
    (_scriptPromise = scriptPromise) != null ? _scriptPromise : scriptPromise = loadScript(gtagScript);
    scriptPromise.then(function () {
      return window.gtag == null ? void 0 : window.gtag('get', googleAnalyticsMeasurementId, field, function (id) {
        // store locally field value
        storedInfo[field] = id; // resolve the promise with the field

        resolve(id);
      });
    })["catch"](function (e) {
      console.error('Error loading gtag for Segment');
    });
  });
};

export var setGoogleConsentMode = function setGoogleConsentMode(hasConsents) {
  var value = hasConsents ? 'granted' : 'denied';
  window.gtag == null ? void 0 : window.gtag('consent', 'update', {
    analytics_storage: value,
    ad_storage: value
  });
};
export var getGoogleClientID = function getGoogleClientID() {
  return getGoogleField(FIELDS.clientId);
};
export var getGoogleSessionID = function getGoogleSessionID() {
  return getGoogleField(FIELDS.sessionId);
};