import { isClient, setConfig } from './config.js';
import { readCookie, saveCookie } from './utils/cookies.js';
var XANDR_ID_SERVER_URL = 'https://secure.adnxs.com/getuidj';
var XANDR_ID_COOKIE = 'adit-xandr-id';
var USER_OPTED_OUT_XANDR_ID_VALUE = 0;
/**
 * [Xandr API Docs]{@link https://docs.xandr.com/bundle/invest_invest-standard/page/topics/user-id-mapping-with-getuid-and-mapuid.html}
 * @returns {String|null} a valid xandrId value
 */

export function getXandrId() {
  if (!isClient) return null; // 0 is invalid. Negative numbers seems to be invalid too.

  var checkValid = function checkValid(xandrId) {
    return xandrId && Number(xandrId) > USER_OPTED_OUT_XANDR_ID_VALUE;
  };

  var storedXandrId = readCookie(XANDR_ID_COOKIE);
  var isValidXandrId = checkValid(storedXandrId);

  if (!isValidXandrId) {
    getRemoteXandrId().then(function (xandrId) {
      if (typeof xandrId === 'string') {
        saveCookie(XANDR_ID_COOKIE, xandrId);
      }
    });
  }

  setConfig('xandrId', storedXandrId);
  return isValidXandrId ? storedXandrId : null;
}
export function getRemoteXandrId() {
  if (!isClient) return Promise.resolve(null);
  return window.fetch(XANDR_ID_SERVER_URL, {
    credentials: 'include'
  }).then(function (response) {
    return response.json();
  }).then(function (json) {
    return json == null ? void 0 : json.uid;
  });
}